==> qtjambi-qt3drender-5.15.4-sources.jar: io/qt/qt3d/render/QSeamlessCubemap.java <==
package io.qt.qt3d.render;


/**
 * <p>Enables seamless cubemap texture filtering</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qseamlesscubemap.html">Qt3DRender::QSeamlessCubemap</a></p>
 */
public class QSeamlessCubemap extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QSeamlessCubemap.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QSeamlessCubemap(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QSeamlessCubemap() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qseamlesscubemap.html#QSeamlessCubemap">Qt3DRender::QSeamlessCubemap::QSeamlessCubemap(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QSeamlessCubemap(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QSeamlessCubemap instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QSeamlessCubemap(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QSeamlessCubemap(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QSeamlessCubemap instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-5.15.10-sources.jar: io/qt/qt3d/render/QSeamlessCubemap.java <==
package io.qt.qt3d.render;


/**
 * <p>Enables seamless cubemap texture filtering</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qseamlesscubemap.html">Qt3DRender::QSeamlessCubemap</a></p>
 */
public class QSeamlessCubemap extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QSeamlessCubemap.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QSeamlessCubemap(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QSeamlessCubemap() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qseamlesscubemap.html#QSeamlessCubemap">Qt3DRender::QSeamlessCubemap::QSeamlessCubemap(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QSeamlessCubemap(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QSeamlessCubemap instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QSeamlessCubemap(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QSeamlessCubemap(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QSeamlessCubemap instance, QDeclarativeConstructor constructor);
    
}
